@@ -1,5 +1,5 @@
-# $Id: Document.pm 36128 2011-11-30 13:05:49Z wsl $
-# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/Document.pm $
+# $Id: Document.pm 42565 2014-11-17 14:06:46Z wsl $
+# $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Document.pm $
 
 use strict;
 use warnings FATAL => 'all';
@@ -24,35 +24,38 @@ sub transform {
 }
 
 sub build {
+	my $name = $self->rootname;
+	my $root = $self->construct($name);
+	$self->setDocumentElement($root);
+
 	$self->hook_next;
+
+	$root = $self->documentElement;
+	$name = $root->nodeName;
+
 	my $cfg = $self->cfg;
 	my $req = $self->req;
-	my $root = $self->documentElement;
-
 	$root->appendChild($self->construct(settings =>
 		[warn => $req->new_warn],
 		[remember => $req->new_remember],
 		[spnego => $req->new_spnego],
 	));
 
-	$root->appendChild($self->construct(nonce => $req->create_nonce));
+	my $ticket = $req->new_session;
+	$root->appendChild($self->construct(nonce => scalar $ticket->create_nonce));
 
-	if(my $uid = $req->uid) {
-		my $exp = $req->new_session->expiration;
+	if(my $uid = $ticket->uid) {
+		my $exp = $ticket->expiration;
 
-		my $session = $self->construct(session =>
+		$root->appendChild($self->construct(session =>
 			[uid => $uid],
 			[organization => $cfg->organization],
-			[start => iso8601(localtime($exp))],
-			[end => iso8601(localtime($exp + $cfg->session_timeout))],
-		);
-
-		$root->appendChild($session);
+			[start => iso8601(gmtime($exp)) . ' GMT'],
+			[end => iso8601(gmtime($exp + $cfg->session_timeout)) . ' GMT'],
+		));
 	}
 
-	my $name = $root->nodeName;
-	$name =~ tr|:|/|;
-	eval { $self->transform($name) };
+	eval { $self->transform($name =~ tr|:|/|r) };
 	warn $@ if $@;
 }
 
@@ -76,6 +79,9 @@ sub response {
 		$res->setcookie($cookie);
 	}
 
+	# intermediate proxies should not cache any page
+	$res->addheader('Cache-Control' => 'private');
+
 	my $sts = $self->cfg->strict_transport_security;
 	$res->setheader('Strict-Transport-Security' => "max-age=$sts")
 		if $sts && $req->https eq 'on';
