@@ -1,5 +1,5 @@
-# $Id: HTTP.pm 36089 2011-11-23 19:23:06Z wsl $
-# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/Error/HTTP.pm $
+# $Id: HTTP.pm 47630 2018-06-25 14:37:01Z wsl $
+# $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Error/HTTP.pm $
 
 use strict;
 use warnings FATAL => 'all';
@@ -11,13 +11,14 @@ use Aselect::UI::Error -self;
 
 field number;
 
-sub type { 'http' }
+use constant type => 'http';
 sub args {
+	my $req = $self->req;
 	return {
 		number => $self->number,
-		url => $self->req->url,
-		page => $self->req->path_translated,
-	}
+		url => $req->url,
+		page => $req->virtual_path,
+	};
 }
 
 sub response {
