@@ -1,5 +1,5 @@
-# $Id: Request.pm 36052 2011-11-17 18:43:03Z wsl $
-# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/Login/Request.pm $
+# $Id: Request.pm 43917 2015-09-22 08:37:08Z wsl $
+# $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Login/Request.pm $
 
 use strict;
 use warnings FATAL => 'all';
@@ -9,9 +9,9 @@ package Aselect::UI::Login::Request;
 
 use Xyzzy::Util qw(parse_bool);
 use Aselect::URL qw(normalize_url valid_http_url);
-use Aselect::Util;
 use Aselect::UI::Ticket;
-use Aselect::UI::Request -self;
+
+use Aselect::Request -self;
 
 param rid => sub {
 	my $self = shift;
@@ -19,7 +19,7 @@ param rid => sub {
 		my $crypto = $self->crypto;
 		my (undef, undef, $origin, $id, $url) =
 			eval { $crypto->check_token('r', $_, $self->cfg->request_timeout) };
-		die $self->error('rid', $@) if $@;
+		die $self->errorpage('rid', "rid: $@") if $@;
 		$self->requestor_origin($origin);
 		$self->requestor_id($id);
 		$self->requestor_url($url);
@@ -37,27 +37,31 @@ param service => sub {
 	my $cfg = $self->cfg;
 
 	$_ = normalize_url($_);
-	die $self->error('service')
-        unless valid_http_url($_);
+	unless(valid_http_url($_)) {
+		warn "rejecting '$_' as a valid service because it is malformed\n";
+		die $self->errorpage('service');
+	}
 
 	my $re = $cfg->urlfilter;
-	die $self->error('service')
-		unless $_ =~ $re;
+	unless($_ =~ $re) {
+		warn "rejecting '$_' as a valid service because it does not match the configured ServiceFilter\n";
+		die $self->errorpage('service');
+	}
 
 	$re = $cfg->servicefilter;
-	die $self->error('service')
-		unless $_ =~ $re;
+	unless($_ =~ $re) {
+		warn "rejecting '$_' as a valid service because it does not match the list of allowed services configured under ServiceFilter\n";
+		die $self->errorpage('service');
+	}
+
+	$_ = $self->apply_https_everywhere($_);
 };
 
 param lt => sub {
 	my $self = shift;
-	$_ = eval { $self->crypto->check_token('lt'.$self->cur_session->token, $_, $self->cfg->request_timeout); 1 };
+	$_ = eval { $self->cur_session->check_lt($_, $self->cfg->request_timeout); 1 };
 };
 
-sub create_lt {
-	return scalar $self->crypto->create_token('lt'.$self->new_session->token);
-}
-
 sub nonce {
 	return super || $self->lt;
 }
@@ -72,7 +76,8 @@ field effective_warn => sub {
 field effective_remember => sub {
 	my $self = shift;
 	return 'true' unless defined $self->rid || defined $self->service;
-	return bool_string($self->bool_param('remember')) if $self->nonce;
+	return bool_string($self->bool_param('remember') // 0)
+		if $self->nonce;
 	return $self->new_remember;
 };
 
@@ -85,38 +90,6 @@ field requestor_origin => sub { shift->rid; return };
 field requestor_id => sub { shift->rid; return };
 field requestor_url => sub { shift->rid; return };
 
-field credentials => sub {
-	my $self = shift;
-	my $requestor_id = $self->requestor_id or return undef;
-	my $uid = $self->uid or return undef;
-	return scalar $self->crypto->create_token('c', $requestor_id, $uid);
-};
-
-field ticket => sub {
-	my $self = shift;
-	my $service = $self->service or return undef;
-	my $uid = $self->uid or return undef;
-	my $renew = $self->renew;
-	return scalar $self->crypto->create_cas_token('ST', $service, $uid, $renew // ());
-};
-
-field cred_url => sub {
-	my $self = shift;
-	if(my $rid = $self->rid) {
-		my $credentials = $self->credentials or return undef;
-		return aselect_url($self->requestor_url, {
-			rid => $rid,
-			'a-select-server' => $self->server_id,
-			aselect_credentials => $credentials,
-		});
-	} elsif(my $service = $self->service) {
-		my $ticket = $self->ticket or return undef;
-		return aselect_url($service, {ticket => $ticket});
-	} else {
-		return $self->script_url . '/status';
-	}
-};
-
 field bare_url => sub {
 	my $self = shift;
 	if(my $requestor_url = $self->requestor_url) {
