@@ -1,5 +1,5 @@
-# $Id: Document.pm 36088 2011-11-23 18:56:52Z wsl $
-# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/Password/Document.pm $
+# $Id: Document.pm 42299 2014-09-26 14:30:54Z wsl $
+# $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Password/Document.pm $
 
 use strict;
 use warnings FATAL => 'all';
@@ -9,15 +9,15 @@ package Aselect::UI::Password::Document;
 
 use Aselect::UI::Login::Document -self;
 
+use constant rootname => 'password';
+
 sub build {
 	my $req = $self->req;
 
-	my $root = $self->construct(password =>
-		[lt => $req->create_lt]
-	);
-	$self->setDocumentElement($root);
+	my $root = $self->documentElement;
+	$root->appendChild($self->construct(lt => scalar $req->new_session->create_lt));
 
-	if(my $username = $req->username || $req->uid) {
+	if(my $username = $req->username) {
 		$root->appendChild($self->construct(username => $username));
 	}
 
