@@ -1,4 +1,4 @@
-# $Id: Request.pm 36638 2012-03-03 14:33:20Z wsl $
+# $Id: Request.pm 46234 2017-02-14 10:23:46Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Session/Request.pm $
 
 use strict;
@@ -11,10 +11,12 @@ use Aselect::Request -self;
 
 field uid => sub {
 	my $self = shift;
-	my $uid = $self->new_session->uid;
 	return undef if $self->renew;
+	my $uid = $self->new_session->uid;
 	return undef unless defined $uid;
-	return $uid eq '' ? undef : $uid;
+	return undef if $uid eq '';
+	return undef unless $self->dir->search($uid)->count;
+	return $uid;
 };
 
 use constant effective_remember => 'false';
