@@ -1,5 +1,5 @@
-# $Id: Request.pm 36052 2011-11-17 18:43:03Z wsl $
-# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/Settings/Request.pm $
+# $Id: Request.pm 37888 2012-09-28 08:00:04Z wsl $
+# $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Settings/Request.pm $
 
 use strict;
 use warnings FATAL => 'all';
@@ -7,18 +7,18 @@ use utf8;
 
 package Aselect::UI::Settings::Request;
 
-use Aselect::UI::Request -self;
+use Aselect::Request -self;
 
 field new_warn => sub {
 	my $self = shift;
 	return $self->cur_warn unless $self->nonce;
-	return bool_string($self->param('warn')) // $self->cur_warn;
+	return bool_string($self->bool_param('warn')) // $self->cur_warn;
 };
 
 field new_remember => sub {
 	my $self = shift;
 	return $self->cur_remember unless $self->nonce;
-	return bool_string($self->param('remember')) // $self->cur_remember;
+	return bool_string($self->bool_param('remember')) // $self->cur_remember;
 };
 
 field new_spnego => sub {
